@@ -1,11 +1,11 @@
 from unittest import TestCase
 
-from pandas_ml_utils.df.model import Model
+from pandas_ml_utils.df_patching.model_patch import DfModelPatch
 from pandas_ml_common_test.config import TEST_DF
 
 
 class TestDfModelExtension(TestCase):
 
     def test__property(self):
-        self.assertIsInstance(TEST_DF.model, Model)
+        self.assertIsInstance(TEST_DF.model, DfModelPatch)
 
